package com.gx.obe.action.bean;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;

import com.gx.obe.action.listener.ActionListener;
import com.gx.obe.util.utils.UuidUtils;
import com.gx.obe.web.entity.auth.Menu;
import com.gx.obe.web.entity.evaluation.EvaluationStep;
import com.gx.obe.web.entity.tender.TenderProjectEntity;
import com.gx.obe.web.entity.tender.TenderProjectRuleEntity;
import com.gx.obe.web.service.ProjectRuleService;
import com.gx.obe.web.service.TenderProjectService;

/**
 * @Description:封装公共action接口 
 * @author guoyr
 */
public abstract class Action {
	private String id = UuidUtils.getUUID();
	private ActionListener listener;
	public abstract void run();
	private Map<String, Object> data = null;
	private TenderProjectEntity parentProject;
	private TenderProjectEntity tenderProject;
	private TenderProjectRuleEntity tenderProjectRule;
	private TenderProjectService tenderProjectService;
	private ProjectRuleService projectRuleService;
	private EvaluationStep evaluationStep;
	
	private Menu menu;
	
	/**
	 * @Description: 添加action监听
	 * @author guoyr
	 * @param listener
	 */
	public void addActionListener(ActionListener listener){
		this.listener = listener;
	}
	

	public TenderProjectEntity refreshParentProject() {
		if(null == tenderProjectService){
			tenderProjectService = new TenderProjectService();
		}
		parentProject = tenderProjectService.getById(parentProject.getId());
		return parentProject;
	}
	
	public TenderProjectEntity refreshTenderProject() {
		if(null == tenderProjectService){
			tenderProjectService = new TenderProjectService();
		}
		tenderProject = tenderProjectService.getById(tenderProject.getId());
		tenderProject.setParentProjectEntity(parentProject);
		return tenderProject;
	}
	

	public TenderProjectRuleEntity refreshTenderProjectRule() {
		if(null == projectRuleService){
			projectRuleService = new ProjectRuleService();
		}
//		if(null != tenderProjectRule && null != tenderProjectRule.getId()){
//		}
		tenderProjectRule = projectRuleService.getProjectRule(tenderProject.getId());
		if(null == tenderProjectRule) {
			tenderProjectRule = new TenderProjectRuleEntity();
			tenderProjectRule.setTenderId(tenderProject.getId());
			tenderProjectRule.setId(UuidUtils.getUUID());
			projectRuleService.insert(tenderProjectRule);
		}
		return tenderProjectRule;
	}
	

	/**
	 * @Description: 获取action监听
	 * @author guoyr
	 * @return
	 */
	public ActionListener getListener() {
		return listener;
	}

	public Menu getMenu() {
		return menu;
	}

	public void setMenu(Menu menu) {
		this.menu = menu;
	}

	
	public TenderProjectEntity getParentProject() {
		return parentProject;
	}

	public void setParentProject(TenderProjectEntity parentProject) {
		this.parentProject = parentProject;
	}

	public TenderProjectEntity getTenderProject() {
		return tenderProject;
	}

	public void setTenderProject(TenderProjectEntity tenderProject) {
		this.tenderProject = tenderProject;
		this.tenderProject.setParentProjectEntity(getParentProject());
	}

	public TenderProjectRuleEntity getTenderProjectRule() {
		return tenderProjectRule;
	}

	public void setTenderProjectRule(TenderProjectRuleEntity tenderProjectRule) {
		this.tenderProjectRule = tenderProjectRule;
	}

	
	public EvaluationStep getEvaluationStep() {
		return evaluationStep;
	}


	public void setEvaluationStep(EvaluationStep evaluationStep) {
		this.evaluationStep = evaluationStep;
	}


	/**
	 * @Description: 设置data数据
	 * @author guoyr
	 * @param key
	 * @param value
	 */
	public void setData(String key, Object value) {
		if(data == null){
			data = new HashMap<String, Object>();
		}
		data.put(key, value);
	}

	public Shell getParentShell(Shell parent){
		if(null != parent && !parent.isDisposed()){
			return parent;
		}else {
			Shell _parentShell = null;
			_parentShell = Display.getDefault().getActiveShell();
			if(null != _parentShell && !_parentShell.isDisposed()){
				return _parentShell;
			}else {
				Shell[] shells = Display.getDefault().getShells();
				if(null != shells && shells.length > 0){
					for(int i = shells.length -1; i >= 0; i--){
						if(null != shells[i] && !shells[i].isDisposed()){
							return shells[i];
						}
					}
				}
			}
		}
		return new Shell(SWT.ON_TOP);
	}
	/**
	 * @Description: 获取data数据
	 * @author guoyr
	 * @param key
	 * @return
	 */
	public Object getData(String key) {
		if(data != null){
			return data.get(key);
		}
		return null;
	}
	@Override
	public String toString() {
		return id;
	}
	
}
